==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/particle/ModParticles.java <==
package net.db64.homelawnsecurity.particle;

import com.mojang.serialization.MapCodec;
import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.fabricmc.fabric.api.particle.v1.FabricParticleTypes;
import net.minecraft.class_2378;
import net.minecraft.class_2394;
import net.minecraft.class_2396;
import net.minecraft.class_2400;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.particle.*;
import java.util.function.Function;

public class ModParticles {
	/*public static final ParticleType<ItemStackParticleEffect>
		MARKER = register(
		"marker", true, ItemStackParticleEffect::createCodec, ItemStackParticleEffect::createPacketCodec
	);*/

	public static void registerParticles() {
		HomeLawnSecurity.LOGGER.info("Registering particles for {}", HomeLawnSecurity.MOD_ID);
	}

	private static class_2400 register(String name, boolean alwaysShow) {
		return class_2378.method_10226(class_7923.field_41180, name, FabricParticleTypes.simple(alwaysShow));
	}

	private static <T extends class_2394> class_2396<T> register(
		String name,
		boolean alwaysShow,
		Function<class_2396<T>, MapCodec<T>> codecGetter,
		Function<class_2396<T>, class_9139<? super class_9129, T>> packetCodecGetter
	) {
		return class_2378.method_10230(class_7923.field_41180, class_2960.method_60655(HomeLawnSecurity.MOD_ID, name), new class_2396<T>(alwaysShow) {
			@Override
			public MapCodec<T> method_29138() {
				return codecGetter.apply(this);
			}

			@Override
			public class_9139<? super class_9129, T> method_56179() {
				return packetCodecGetter.apply(this);
			}
		});
	}
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/particle/ModParticles.java <==
package net.db64.homelawnsecurity.particle;

import com.mojang.serialization.MapCodec;
import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.particle.custom.EntityParticleRenderer;
import net.db64.homelawnsecurity.particle.custom.MarkerParticle;
import net.fabricmc.fabric.api.client.particle.v1.ParticleFactoryRegistry;
import net.fabricmc.fabric.api.client.particle.v1.ParticleRendererRegistry;
import net.fabricmc.fabric.api.particle.v1.FabricParticleTypes;
import net.minecraft.class_2378;
import net.minecraft.class_2392;
import net.minecraft.class_2394;
import net.minecraft.class_2396;
import net.minecraft.class_2400;
import net.minecraft.class_2960;
import net.minecraft.class_3999;
import net.minecraft.class_7923;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.particle.*;
import java.util.function.Function;

public class ModParticles {
	public static final class_2396<class_2392>
		MARKER = register(
			"marker", true, class_2392::method_29136, class_2392::method_56178
	);

	public static final class_3999 SHEET_ENTITY = new class_3999("pvz_entity");

	public static void registerParticles() {
		HomeLawnSecurity.LOGGER.info("Registering particles for {}", HomeLawnSecurity.MOD_ID);

		ParticleRendererRegistry.register(SHEET_ENTITY, EntityParticleRenderer::new);
		ParticleFactoryRegistry.getInstance().register(MARKER, new MarkerParticle.Factory());
	}

	private static class_2400 register(String name, boolean alwaysShow) {
		return class_2378.method_10226(class_7923.field_41180, name, FabricParticleTypes.simple(alwaysShow));
	}

	private static <T extends class_2394> class_2396<T> register(
		String name,
		boolean alwaysShow,
		Function<class_2396<T>, MapCodec<T>> codecGetter,
		Function<class_2396<T>, class_9139<? super class_9129, T>> packetCodecGetter
	) {
		return class_2378.method_10230(class_7923.field_41180, class_2960.method_60655(HomeLawnSecurity.MOD_ID, name), new class_2396<T>(alwaysShow) {
			@Override
			public MapCodec<T> method_29138() {
				return codecGetter.apply(this);
			}

			@Override
			public class_9139<? super class_9129, T> method_56179() {
				return packetCodecGetter.apply(this);
			}
		});
	}
}
